translate.storage.statistics.Statistics

Package translate :: Package storage :: Module statistics :: Class Statistics |
[hide private]
[frames] | no frames]

# Class Statistics

source code

Manages statistics for storage objects.

Instance Methods | [hide private]
__init__(self, sourcelanguage=`'``en``'`, targetlanguage=`'``en``'`, checkerstyle=None) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
init_checker(self, checkerstyle=None) | source code
fuzzy_units(self) Return a list of fuzzy units. | source code
fuzzy_unitcount(self) Returns the number of fuzzy units. | source code
translated_units(self) Return a list of translated units. | source code
translated_unitcount(self) Returns the number of translated units. | source code
untranslated_units(self) Return a list of untranslated units. | source code
untranslated_unitcount(self) Returns the number of untranslated units. | source code
getunits(self) Returns a list of all units in this object. | source code
get_source_text(self, units) Joins the unit source strings in a single string of text. | source code
wordcount(self, text) Returns the number of words in the given text. | source code
source_wordcount(self) Returns the number of words in the source text. | source code
translated_wordcount(self) Returns the number of translated words in this object. | source code
untranslated_wordcount(self) Returns the number of untranslated words in this object. | source code
classifyunit(self, unit) Returns a list of the classes that the unit belongs to. | source code
classifyunits(self) Makes a dictionary of which units fall into which classifications. | source code
countwords(self) Counts the source and target words in each of the units. | source code
reclassifyunit(self, item) Updates the classification of a unit in self.classification. | source code
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, sourcelanguage=`'``en``'`, targetlanguage=`'``en``'`, checkerstyle=None) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### classifyunit(self, unit) | source code
Returns a list of the classes that the unit belongs to. Parameters: `unit` - the unit to classify

### classifyunits(self) | source code
Makes a dictionary of which units fall into which classifications. This method iterates over all units.

### reclassifyunit(self, item) | source code
Updates the classification of a unit in self.classification. Parameters: `item` - an integer that is an index in .getunits().